==> 2.0.0.tar.gz: argos/dmp-backend/core/src/main/java/eu/eudat/audit/AuditableAction.java <==
package eu.eudat.audit;

import gr.cite.tools.logging.EventId;

public class AuditableAction {

    public static final EventId DescriptionTemplateType_Query = new EventId(1000, "DescriptionTemplateType_Query");
    public static final EventId DescriptionTemplateType_Lookup = new EventId(1001, "DescriptionTemplateType_Lookup");
    public static final EventId DescriptionTemplateType_Persist = new EventId(1002, "DescriptionTemplateType_Persist");
    public static final EventId DescriptionTemplateType_Delete = new EventId(1003, "DescriptionTemplateType_Delete");

    public static final EventId EntityDoi_Query = new EventId(2000, "EntityDoi_Query");
    public static final EventId EntityDoi_Lookup = new EventId(2001, "EntityDoi_Lookup");
    public static final EventId EntityDoi_Persist = new EventId(2002, "EntityDoi_Persist");
    public static final EventId EntityDoi_Delete = new EventId(2003, "EntityDoi_Delete");

    public static final EventId DmpBlueprint_Query = new EventId(3000, "DmpBlueprint_Query");
    public static final EventId DmpBlueprint_Lookup = new EventId(3001, "DmpBlueprint_Lookup");
    public static final EventId DmpBlueprint_Persist = new EventId(3002, "DmpBlueprint_Persist");
    public static final EventId DmpBlueprint_Delete = new EventId(3003, "DmpBlueprint_Delete");
    public static final EventId DmpBlueprint_Clone = new EventId(3004, "DmpBlueprint_Clone");

    public static final EventId DmpBlueprint_PersistNewVersion = new EventId(3005, "DmpBlueprint_PersistNewVersion");
    public static final EventId DmpBlueprint_GetXml = new EventId(3006, "DmpBlueprint_GetXml");
    public static final EventId DmpBlueprint_Import = new EventId(3007, "DmpBlueprint_Import");

    public static final EventId User_Settings_Query = new EventId(4000, "User_Settings_Query");
    public static final EventId User_Settings_Lookup = new EventId(4001, "User_Settings_Lookup");
    public static final EventId User_Settings_Persist = new EventId(4002, "User_Settings_Persist");
    public static final EventId User_Settings_Delete = new EventId(4003, "User_Settings_Delete");

    public static final EventId Dmp_Query = new EventId(5000, "Dmp_Query");
    public static final EventId Dmp_Lookup = new EventId(5001, "Dmp_Lookup");
    public static final EventId Dmp_Persist = new EventId(5002, "Dmp_Persist");
    public static final EventId Dmp_Delete = new EventId(5003, "Dmp_Delete");
    public static final EventId Dmp_Clone = new EventId(5004, "Dmp_Clone");
    public static final EventId Dmp_PersistNewVersion = new EventId(5005, "Dmp_PersistNewVersion");
    public static final EventId Dmp_Assign_Users = new EventId(5006, "Dmp_Assign_Users");
    public static final EventId Dmp_RemoveUser = new EventId(5007, "Dmp_RemoveUser");
    public static final EventId Dmp_Invite_Users = new EventId(5008, "Dmp_Invite_Users");
    public static final EventId Dmp_Invite_Accept = new EventId(5009, "Dmp_Invite_Accept");
    public static final EventId Dmp_PublicQuery = new EventId(5010, "Dmp_PublicQuery");
    
    public static final EventId Description_Query = new EventId(6000, "Description_Query");
    public static final EventId Description_Lookup = new EventId(6001, "Description_Lookup");
    public static final EventId Description_Persist = new EventId(6002, "Description_Persist");
    public static final EventId Description_Delete = new EventId(6003, "Description_Delete");
    public static final EventId Description_PublicQuery = new EventId(6004, "Description_PublicQuery");
    public static final EventId Description_PublicLookup = new EventId(6005, "Description_PublicLookup");
    public static final EventId Description_PersistStatus = new EventId(6006, "Description_PersistStatus");
    public static final EventId Description_UploadFieldFiles = new EventId(6007, "Description_UploadFieldFiles");
    public static final EventId Description_GetFieldFile = new EventId(6008, "Description_GetFieldFile");
    
    
    public static final EventId Reference_Query = new EventId(7000, "Reference_Query");
    public static final EventId Reference_Lookup = new EventId(7001, "Reference_Lookup");
    public static final EventId Reference_Persist = new EventId(7002, "Reference_Persist");
    public static final EventId Reference_Delete = new EventId(7003, "Reference_Delete");
    public static final EventId Reference_Search = new EventId(7004, "Reference_Search");
    
    public static final EventId DescriptionTemplate_Query = new EventId(8000, "DescriptionTemplate_Query");
    public static final EventId DescriptionTemplate_Lookup = new EventId(8001, "DescriptionTemplate_Lookup");
    public static final EventId DescriptionTemplate_Persist = new EventId(8002, "DescriptionTemplate_Persist");
    public static final EventId DescriptionTemplate_Delete = new EventId(8003, "DescriptionTemplate_Delete");
    public static final EventId DescriptionTemplate_Clone = new EventId(8004, "DescriptionTemplate_Clone");
    public static final EventId DescriptionTemplate_PersistNewVersion = new EventId(8005, "DescriptionTemplate_PersistNewVersion");
    public static final EventId DescriptionTemplate_GetXml = new EventId(8006, "DescriptionTemplate_GetXml");
    public static final EventId DescriptionTemplate_Import = new EventId(8007, "DescriptionTemplate_Import");
    
    public static final EventId SupportiveMaterial_Query = new EventId(9000, "SupportiveMaterial_Query");
    public static final EventId SupportiveMaterial_Lookup = new EventId(9001, "SupportiveMaterial_Lookup");
    public static final EventId SupportiveMaterial_Persist = new EventId(9002, "SupportiveMaterial_Persist");
    public static final EventId SupportiveMaterial_Delete = new EventId(9003, "SupportiveMaterial_Delete");

    public static final EventId ReferenceType_Query = new EventId(10000, "ReferenceType_Query");
    public static final EventId ReferenceType_Lookup = new EventId(10001, "ReferenceType_Lookup");
    public static final EventId ReferenceType_Persist = new EventId(10002, "ReferenceType_Persist");
    public static final EventId ReferenceType_Delete = new EventId(10003, "ReferenceType_Delete");

    public static final EventId User_Query = new EventId(11000, "User_Query");
    public static final EventId User_Lookup = new EventId(11001, "User_Lookup");
    public static final EventId User_Persist = new EventId(11002, "User_Persist");
    public static final EventId User_Delete = new EventId(11003, "User_Delete");
    public static final EventId User_LookupByEmail = new EventId(11004, "User_LookupByEmail");
    public static final EventId User_ExportCsv = new EventId(11005, "User_ExportCsv");
    public static final EventId User_PersistRoles = new EventId(11006, "User_PersistRoles");
    public static final EventId User_LanguageMine = new EventId(11007, "User_LanguageMine");
    public static final EventId User_TimezoneMine = new EventId(11008, "User_TimezoneMine");
    public static final EventId User_CultureMine = new EventId(11009, "User_CultureMine");
    public static final EventId User_MergeRequest = new EventId(11010, "User_MergeRequest");
    public static final EventId User_MergeConfirm = new EventId(11011, "User_MergeConfirm");
    public static final EventId User_RemoveCredentialRequest = new EventId(11012, "User_RemoveCredentialRequest");
    public static final EventId User_RemoveCredentialConfirm = new EventId(11013, "User_RemoveCredentialConfirm");
    public static final EventId User_DmpAssociatedQuery = new EventId(11014, "User_DmpAssociatedQuery");

    public static final EventId Tenant_Query = new EventId(12000, "Tenant_Query");
    public static final EventId Tenant_Lookup = new EventId(12001, "Tenant_Lookup");
    public static final EventId Tenant_Persist = new EventId(12002, "Tenant_Persist");
    public static final EventId Tenant_Delete = new EventId(12003, "Tenant_Delete");
    
    public static final EventId Language_Query = new EventId(13000, "Language_Query");
    public static final EventId Language_Lookup = new EventId(13001, "Language_Lookup");
    public static final EventId Language_Persist = new EventId(13002, "Language_Persist");
    public static final EventId Language_Delete = new EventId(13003, "Language_Delete");

    public static final EventId StorageFile_Download = new EventId(14000, "StorageFile_Download");
    public static final EventId StorageFile_Upload = new EventId(14001, "StorageFile_Upload");

    public static final EventId Dashboard_MyRecentActivityItems = new EventId(15000, "Dashboard_MyRecentActivityItems");
    public static final EventId Dashboard_MyDashboardStatistics = new EventId(15001, "Dashboard_MyDashboardStatistics");
    public static final EventId Dashboard_PublicDashboardStatistics = new EventId(15002, "Dashboard_PublicDashboardStatistics");

    public static final EventId Notification_Persist = new EventId(16000, "Notification_Persist");

    public static final EventId Lock_Query = new EventId(17000, "Lock_Query");
    public static final EventId Lock_Lookup = new EventId(17001, "Lock_Lookup");
    public static final EventId Lock_Persist = new EventId(17002, "Lock_Persist");
    public static final EventId Lock_Delete = new EventId(17003, "Lock_Delete");
    public static final EventId Lock_IsLocked = new EventId(17004, "Lock_IsLocked");
    public static final EventId Lock_UnLocked = new EventId(17005, "Lock_UnLocked");

    public static final EventId Deposit_GetAvailableRepositories = new EventId(18000, "Deposit_GetAvailableRepositories");
    public static final EventId Deposit_GetAccessToken = new EventId(18001, "Deposit_GetAccessToken");
    public static final EventId Deposit_Deposit = new EventId(18002, "Deposit_Deposit");
    public static final EventId Deposit_GetLogo = new EventId(18003, "Deposit_GetLogo");

    public static final EventId Tag_Query = new EventId(19000, "Tag_Query");
    public static final EventId Tag_Lookup = new EventId(19001, "Tag_Lookup");
    public static final EventId Tag_Persist = new EventId(19002, "Tag_Persist");
    public static final EventId Tag_Delete = new EventId(19003, "Tag_Delete");

    public static final EventId FileTransformer_GetAvailableConfigurations = new EventId(20000, "FileTransformer_GetAvailableConfigurations");

    public static final EventId ContactSupport_Sent = new EventId(210000, "ContactSupport_Sent");
    public static final EventId ContactSupport_PublicSent = new EventId(210001, "ContactSupport_PublicSent");

    public static final EventId Prefilling_Query = new EventId(220000, "Prefilling_Query");
    public static final EventId Prefilling_Generate = new EventId(210001, "Prefilling_Generate");
    public static final EventId Prefilling_GenerateWithData = new EventId(210002, "Prefilling_GenerateWithData");

    public static final EventId Maintenance_GenerateElastic = new EventId(220000, "Maintenance_GenerateElastic");
    public static final EventId Maintenance_ClearElastic = new EventId(230000, "Maintenance_ClearElastic");
    
    public static final EventId Principal_Lookup = new EventId(240000, "Principal_Lookup");

    public static final EventId GetSemantics = new EventId(250000, "GetSemantics");

    
}

==> 2.0.1.tar.gz: argos/dmp-backend/core/src/main/java/eu/eudat/audit/AuditableAction.java <==
package eu.eudat.audit;

import gr.cite.tools.logging.EventId;

public class AuditableAction {

    public static final EventId DescriptionTemplateType_Query = new EventId(1000, "DescriptionTemplateType_Query");
    public static final EventId DescriptionTemplateType_Lookup = new EventId(1001, "DescriptionTemplateType_Lookup");
    public static final EventId DescriptionTemplateType_Persist = new EventId(1002, "DescriptionTemplateType_Persist");
    public static final EventId DescriptionTemplateType_Delete = new EventId(1003, "DescriptionTemplateType_Delete");

    public static final EventId EntityDoi_Query = new EventId(2000, "EntityDoi_Query");
    public static final EventId EntityDoi_Lookup = new EventId(2001, "EntityDoi_Lookup");
    public static final EventId EntityDoi_Persist = new EventId(2002, "EntityDoi_Persist");
    public static final EventId EntityDoi_Delete = new EventId(2003, "EntityDoi_Delete");

    public static final EventId DmpBlueprint_Query = new EventId(3000, "DmpBlueprint_Query");
    public static final EventId DmpBlueprint_Lookup = new EventId(3001, "DmpBlueprint_Lookup");
    public static final EventId DmpBlueprint_Persist = new EventId(3002, "DmpBlueprint_Persist");
    public static final EventId DmpBlueprint_Delete = new EventId(3003, "DmpBlueprint_Delete");
    public static final EventId DmpBlueprint_Clone = new EventId(3004, "DmpBlueprint_Clone");

    public static final EventId DmpBlueprint_PersistNewVersion = new EventId(3005, "DmpBlueprint_PersistNewVersion");
    public static final EventId DmpBlueprint_GetXml = new EventId(3006, "DmpBlueprint_GetXml");
    public static final EventId DmpBlueprint_Import = new EventId(3007, "DmpBlueprint_Import");

    public static final EventId User_Settings_Query = new EventId(4000, "User_Settings_Query");
    public static final EventId User_Settings_Lookup = new EventId(4001, "User_Settings_Lookup");
    public static final EventId User_Settings_Persist = new EventId(4002, "User_Settings_Persist");
    public static final EventId User_Settings_Delete = new EventId(4003, "User_Settings_Delete");

    public static final EventId Dmp_Query = new EventId(5000, "Dmp_Query");
    public static final EventId Dmp_Lookup = new EventId(5001, "Dmp_Lookup");
    public static final EventId Dmp_Persist = new EventId(5002, "Dmp_Persist");
    public static final EventId Dmp_Delete = new EventId(5003, "Dmp_Delete");
    public static final EventId Dmp_Clone = new EventId(5004, "Dmp_Clone");
    public static final EventId Dmp_PersistNewVersion = new EventId(5005, "Dmp_PersistNewVersion");
    public static final EventId Dmp_Assign_Users = new EventId(5006, "Dmp_Assign_Users");
    public static final EventId Dmp_RemoveUser = new EventId(5007, "Dmp_RemoveUser");
    public static final EventId Dmp_Invite_Users = new EventId(5008, "Dmp_Invite_Users");
    public static final EventId Dmp_Invite_Accept = new EventId(5009, "Dmp_Invite_Accept");
    public static final EventId Dmp_PublicQuery = new EventId(5010, "Dmp_PublicQuery");
    public static final EventId Dmp_PublicLookup = new EventId(5011, "Dmp_PublicLookup");
    
    public static final EventId Description_Query = new EventId(6000, "Description_Query");
    public static final EventId Description_Lookup = new EventId(6001, "Description_Lookup");
    public static final EventId Description_Persist = new EventId(6002, "Description_Persist");
    public static final EventId Description_Delete = new EventId(6003, "Description_Delete");
    public static final EventId Description_PublicQuery = new EventId(6004, "Description_PublicQuery");
    public static final EventId Description_PublicLookup = new EventId(6005, "Description_PublicLookup");
    public static final EventId Description_PersistStatus = new EventId(6006, "Description_PersistStatus");
    public static final EventId Description_UploadFieldFiles = new EventId(6007, "Description_UploadFieldFiles");
    public static final EventId Description_GetFieldFile = new EventId(6008, "Description_GetFieldFile");
    
    
    public static final EventId Reference_Query = new EventId(7000, "Reference_Query");
    public static final EventId Reference_Lookup = new EventId(7001, "Reference_Lookup");
    public static final EventId Reference_Persist = new EventId(7002, "Reference_Persist");
    public static final EventId Reference_Delete = new EventId(7003, "Reference_Delete");
    public static final EventId Reference_Search = new EventId(7004, "Reference_Search");
    
    public static final EventId DescriptionTemplate_Query = new EventId(8000, "DescriptionTemplate_Query");
    public static final EventId DescriptionTemplate_Lookup = new EventId(8001, "DescriptionTemplate_Lookup");
    public static final EventId DescriptionTemplate_Persist = new EventId(8002, "DescriptionTemplate_Persist");
    public static final EventId DescriptionTemplate_Delete = new EventId(8003, "DescriptionTemplate_Delete");
    public static final EventId DescriptionTemplate_Clone = new EventId(8004, "DescriptionTemplate_Clone");
    public static final EventId DescriptionTemplate_PersistNewVersion = new EventId(8005, "DescriptionTemplate_PersistNewVersion");
    public static final EventId DescriptionTemplate_GetXml = new EventId(8006, "DescriptionTemplate_GetXml");
    public static final EventId DescriptionTemplate_Import = new EventId(8007, "DescriptionTemplate_Import");
    
    public static final EventId SupportiveMaterial_Query = new EventId(9000, "SupportiveMaterial_Query");
    public static final EventId SupportiveMaterial_Lookup = new EventId(9001, "SupportiveMaterial_Lookup");
    public static final EventId SupportiveMaterial_Persist = new EventId(9002, "SupportiveMaterial_Persist");
    public static final EventId SupportiveMaterial_Delete = new EventId(9003, "SupportiveMaterial_Delete");

    public static final EventId ReferenceType_Query = new EventId(10000, "ReferenceType_Query");
    public static final EventId ReferenceType_Lookup = new EventId(10001, "ReferenceType_Lookup");
    public static final EventId ReferenceType_Persist = new EventId(10002, "ReferenceType_Persist");
    public static final EventId ReferenceType_Delete = new EventId(10003, "ReferenceType_Delete");

    public static final EventId User_Query = new EventId(11000, "User_Query");
    public static final EventId User_Lookup = new EventId(11001, "User_Lookup");
    public static final EventId User_Persist = new EventId(11002, "User_Persist");
    public static final EventId User_Delete = new EventId(11003, "User_Delete");
    public static final EventId User_LookupByEmail = new EventId(11004, "User_LookupByEmail");
    public static final EventId User_ExportCsv = new EventId(11005, "User_ExportCsv");
    public static final EventId User_PersistRoles = new EventId(11006, "User_PersistRoles");
    public static final EventId User_LanguageMine = new EventId(11007, "User_LanguageMine");
    public static final EventId User_TimezoneMine = new EventId(11008, "User_TimezoneMine");
    public static final EventId User_CultureMine = new EventId(11009, "User_CultureMine");
    public static final EventId User_MergeRequest = new EventId(11010, "User_MergeRequest");
    public static final EventId User_MergeConfirm = new EventId(11011, "User_MergeConfirm");
    public static final EventId User_RemoveCredentialRequest = new EventId(11012, "User_RemoveCredentialRequest");
    public static final EventId User_RemoveCredentialConfirm = new EventId(11013, "User_RemoveCredentialConfirm");
    public static final EventId User_DmpAssociatedQuery = new EventId(11014, "User_DmpAssociatedQuery");

    public static final EventId Tenant_Query = new EventId(12000, "Tenant_Query");
    public static final EventId Tenant_Lookup = new EventId(12001, "Tenant_Lookup");
    public static final EventId Tenant_Persist = new EventId(12002, "Tenant_Persist");
    public static final EventId Tenant_Delete = new EventId(12003, "Tenant_Delete");
    
    public static final EventId Language_Query = new EventId(13000, "Language_Query");
    public static final EventId Language_Lookup = new EventId(13001, "Language_Lookup");
    public static final EventId Language_Persist = new EventId(13002, "Language_Persist");
    public static final EventId Language_Delete = new EventId(13003, "Language_Delete");

    public static final EventId StorageFile_Download = new EventId(14000, "StorageFile_Download");
    public static final EventId StorageFile_Upload = new EventId(14001, "StorageFile_Upload");

    public static final EventId Dashboard_MyRecentActivityItems = new EventId(15000, "Dashboard_MyRecentActivityItems");
    public static final EventId Dashboard_MyDashboardStatistics = new EventId(15001, "Dashboard_MyDashboardStatistics");
    public static final EventId Dashboard_PublicDashboardStatistics = new EventId(15002, "Dashboard_PublicDashboardStatistics");

    public static final EventId Notification_Persist = new EventId(16000, "Notification_Persist");

    public static final EventId Lock_Query = new EventId(17000, "Lock_Query");
    public static final EventId Lock_Lookup = new EventId(17001, "Lock_Lookup");
    public static final EventId Lock_Persist = new EventId(17002, "Lock_Persist");
    public static final EventId Lock_Delete = new EventId(17003, "Lock_Delete");
    public static final EventId Lock_IsLocked = new EventId(17004, "Lock_IsLocked");
    public static final EventId Lock_UnLocked = new EventId(17005, "Lock_UnLocked");

    public static final EventId Deposit_GetAvailableRepositories = new EventId(18000, "Deposit_GetAvailableRepositories");
    public static final EventId Deposit_GetAccessToken = new EventId(18001, "Deposit_GetAccessToken");
    public static final EventId Deposit_Deposit = new EventId(18002, "Deposit_Deposit");
    public static final EventId Deposit_GetLogo = new EventId(18003, "Deposit_GetLogo");

    public static final EventId Tag_Query = new EventId(19000, "Tag_Query");
    public static final EventId Tag_Lookup = new EventId(19001, "Tag_Lookup");
    public static final EventId Tag_Persist = new EventId(19002, "Tag_Persist");
    public static final EventId Tag_Delete = new EventId(19003, "Tag_Delete");

    public static final EventId FileTransformer_GetAvailableConfigurations = new EventId(20000, "FileTransformer_GetAvailableConfigurations");

    public static final EventId ContactSupport_Sent = new EventId(210000, "ContactSupport_Sent");
    public static final EventId ContactSupport_PublicSent = new EventId(210001, "ContactSupport_PublicSent");

    public static final EventId Maintenance_GenerateElastic = new EventId(220000, "Maintenance_GenerateElastic");
    public static final EventId Maintenance_ClearElastic = new EventId(230000, "Maintenance_ClearElastic");
    
    public static final EventId Principal_Lookup = new EventId(240000, "Principal_Lookup");

    public static final EventId GetSemantics = new EventId(250000, "GetSemantics");

    public static final EventId PrefillingSource_Query = new EventId(260000, "PrefillingSource_Query");
    public static final EventId PrefillingSource_Lookup = new EventId(260001, "PrefillingSource_Lookup");
    public static final EventId PrefillingSource_Persist = new EventId(260002, "PrefillingSource_Persist");
    public static final EventId PrefillingSource_Delete = new EventId(260003, "PrefillingSource_Delete");
    public static final EventId PrefillingSource_Generate = new EventId(260004, "PrefillingSource_Generate");

    
}
